@@ -12,12 +12,12 @@ def convert(my_name):
 class Data():
     def __init__(self) -> None:
         pass
-    def add_dataset(dataset):
+    def add_dataset(self,dataset):
         print(dataset)
-    def show_dataset():
+    def show_dataset(self):
         import seaborn
         return seaborn.get_dataset_names()
-    def load_dataset(name):
+    def load_dataset(self,name):
         import seaborn
         dataset = seaborn.load_dataset(name)
         return dataset
\ No newline at end of file
